/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-07-01
 * Description : image collection selector
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 * Copyright (C) 2004-2005 by Renchi Raju <renchi.raju at kdemail.net>
 * Copyright (C) 2004-2005 by Jesper K. Pedersen <blackie at kde.org>
 * Copyright (C) 2004-2005 by Aurelien Gateau <aurelien dot gateau at free.fr>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef IMAGECOLLECTIONSELECTOR_H
#define IMAGECOLLECTIONSELECTOR_H

// Qt includes.

#include <qwidget.h>
#include <qvaluelist.h>
#include <qpixmap.h>

// KIPI includes.

#include "libkipi/imagecollection.h"
#include "libkipi/libkipi_export.h"

class QListViewItem;
class KFileItem;

namespace KIPI 
{

class Interface;

class LIBKIPI_EXPORT ImageCollectionSelector : public QWidget 
{
Q_OBJECT

    class Private;

public:

    ImageCollectionSelector(QWidget* parent, Interface*, const char* name=0);
    ~ImageCollectionSelector();

    QValueList<ImageCollection> selectedImageCollections() const;

signals:

    void selectionChanged(void);

private slots:

    void slotSelectAll();
    void slotInvertSelection();
    void slotSelectNone();
    void slotSelectionChanged(QListViewItem* listItem);
    void slotGotPreview(const KFileItem*, const QPixmap&);
    void slotInitialShow();


private:

    Private* d;
    void fillList();
    void emitSelectionChanged();
    friend class ImageCollectionItem;
};

} // KIPI


#endif /* IMAGECOLLECTIONSELECTOR_H */
